# Attini CDK

The Attini CDK is currently an experimental feature.

## How to use

The Attini CDK Constructs are used to generate a CloudFormation template for
(attini deplyment plans)[https://attini.io/attini-concepts/].
